/* eslint-disable react/jsx-props-no-spreading */
import React, { FC, useState } from 'react';
import {
  Dialog,
  DialogActions,
  DialogContent,
  DialogContentText,
  DialogTitle,
  Button,
  Typography,
} from '@material-ui/core';
import { InsertReservationType } from 'types/InsertReservationType';
import { SeniorSearchQueryType } from 'types/SeniorSearchQueryType';
import { getRoleObject } from 'api/getRoleObject';
import { setReservation } from 'api/setReservation';
import { SubmitHandler, useForm } from 'react-hook-form';
import { SeniorSearch } from './Reservation/SeniorSearch/SeniorSearch';
import { TripStage } from './Reservation/TripStage';

type ReservationDialogProps = {
  handleClose: () => void;
  isOpen: boolean;
};
export const ReservationDialog: FC<ReservationDialogProps> = ({
  handleClose,
  isOpen,
}: ReservationDialogProps) => {
  const { control, handleSubmit } = useForm<InsertReservationType>({
    mode: 'onSubmit',
  });

  const [senior, setSenior] = useState<SeniorSearchQueryType | null>(null);

  const onSubmit: SubmitHandler<InsertReservationType> = (
    reservation: InsertReservationType,
  ) => {
    const filledReservation = reservation;
    getRoleObject().then((role) => {
      filledReservation.insertedBy = role.id;
      filledReservation.senior = senior?.id;
      setReservation(filledReservation);
    });
    handleClose();
  };

  return (
    <div data-testid="ReservationDialog">
      <Dialog
        open={isOpen}
        onClose={handleClose}
        aria-labelledby="form-dialog-title"
      >
        <form onSubmit={handleSubmit(onSubmit)} data-testid="Form">
          <DialogTitle id="form-dialog-title">
            <Typography variant="h1" component="h1">
              Book New Reservation
            </Typography>
          </DialogTitle>
          <DialogContent>
            <DialogContentText>
              Write here below the details of your next reservation
            </DialogContentText>
            <Typography variant="h2" component="h2">
              Search
            </Typography>
            <SeniorSearch senior={senior} setSenior={setSenior} />
            <Typography variant="h2" component="h2">
              Trip stage
            </Typography>
            <TripStage control={control} />
          </DialogContent>
          <DialogActions>
            <Button onClick={handleClose} color="primary">
              Cancel
            </Button>
            <Button type="submit" fullWidth variant="contained" color="primary">
              Insert
            </Button>
          </DialogActions>
        </form>
      </Dialog>
    </div>
  );
};
